@@ -6,39 +6,45 @@
 #' \url{https://developers.google.com/maps/terms}.
 #'
 #' @param center the center of the map.  Either a longitude/latitude numeric
-#'    vector, a string address (note that the latter uses \code{geocode}).
-#' @param zoom map zoom, an integer from 3 (continent) to 21 (building),
-#'    default value 10 (city)
-#' @param size rectangular dimensions of map in pixels - horizontal x vertical
-#'   - with a max of c(640, 640). this parameter is affected in a
-#'   multiplicative way by scale.
-#' @param scale multiplicative factor for the number of pixels returned
-#'   possible values are 1, 2, or 4 (e.g. size = c(640,640) and scale = 2
-#'   returns an image with 1280x1280 pixels).  4 is reserved for google business
-#'   users only.  scale also affects the size of labels as well.
+#'   vector, a string address (note that the latter uses \code{geocode} with
+#'   \code{source = "google"}).
+#' @param zoom map zoom, an integer from 3 (continent) to 21 (building), default
+#'   value 10 (city)
+#' @param size rectangular dimensions of map in pixels - horizontal x vertical -
+#'   with a max of c(640, 640). this parameter is affected in a multiplicative
+#'   way by scale.
+#' @param scale multiplicative factor for the number of pixels returned possible
+#'   values are 1, 2, or 4 (e.g. size = c(640,640) and scale = 2 returns an
+#'   image with 1280x1280 pixels).  4 is reserved for google business users
+#'   only.  scale also affects the size of labels as well.
 #' @param format character string providing image format - png, jpeg, and gif
 #'   formats available in various flavors
 #' @param maptype character string providing google map theme. options available
 #'   are "terrain", "satellite", "roadmap", and "hybrid"
-#' @param language character string providing language of map labels (for
-#'   themes with them) in the format "en-EN".  not all languages are supported;
-#'   for those which aren't the default language is used
-#' @param sensor specifies whether the application requesting the static map
-#'   is using a sensor to determine the user's location
+#' @param language character string providing language of map labels (for themes
+#'   with them) in the format "en-EN".  not all languages are supported; for
+#'   those which aren't the default language is used
+#' @param sensor specifies whether the application requesting the static map is
+#'   using a sensor to determine the user's location
 #' @param messaging turn messaging on/off
 #' @param urlonly return url only
-#' @param filename destination file for download (file extension added according to format)
+#' @param filename destination file for download (file extension added according
+#'   to format)
 #' @param color color or black-and-white
 #' @param force if the map is on file, should a new map be looked up?
-#' @param where where should the file drawer be located (without terminating "/")
-#' @param archiving use archived maps.  note: by changing to TRUE you agree to the one of the approved uses listed in the Google Maps API Terms of Service : http://developers.google.com/maps/terms.
+#' @param where where should the file drawer be located (without terminating
+#'   "/")
+#' @param archiving use archived maps.  note: by changing to TRUE you agree to
+#'   the one of the approved uses listed in the Google Maps API Terms of Service
+#'   : http://developers.google.com/maps/terms.
 #' @param key an api_key for business users
 #' @param region borders to display as a region code specified as a
 #'   two-character ccTLD ("top-level domain") value, see
 #'   \url{http://en.wikipedia.org/wiki/List_of_Internet_top-level_domains#Country_code_top-level_domains}
+#'
 #' @param markers data.frame with first column longitude, second column
-#'   latitude, for which google markers should be embedded in the map image,
-#'   or character string to be passed directly to api
+#'   latitude, for which google markers should be embedded in the map image, or
+#'   character string to be passed directly to api
 #' @param path data.frame (or list of data.frames) with first column longitude,
 #'   second column latitude, for which a single path should be embedded in the
 #'   map image, or character string to be passed directly to api
@@ -46,19 +52,25 @@
 #'   frame with first column longitude, second latitude) or vector of character
 #'   string addresses which should be visible in map extent
 #' @param style character string to be supplied directly to the api for the
-#'   style argument or a named vector (see examples). this is a powerful complex specification, see
+#'   style argument or a named vector (see examples). this is a powerful complex
+#'   specification, see
 #'   \url{https://developers.google.com/maps/documentation/staticmaps/}
-#' @return a ggmap object (a classed raster object with a bounding box attribute)
+#' @return a ggmap object (a classed raster object with a bounding box
+#'   attribute)
 #' @param ... ...
 #' @author David Kahle \email{david.kahle@@gmail.com}
-#' @seealso \url{https://developers.google.com/maps/documentation/staticmaps/}, \code{\link{ggmap}}
+#' @seealso \url{https://developers.google.com/maps/documentation/staticmaps/},
+#'   \code{\link{ggmap}}
 #' @export
 #' @examples
 #'
+#' \dontrun{ # to diminish run check time
+#'
+#'
 #' get_googlemap(urlonly = TRUE)
 #' ggmap(get_googlemap())
 #'
-
+#'
 #' # markers and paths are easy to access
 #' d <- function(x=-95.36, y=29.76, n,r,a){
 #'   round(data.frame(
@@ -95,7 +107,7 @@
 #'
 #'
 #'
-#'
+#' }
 #'
 get_googlemap <- function(
   center = c(lon = -95.3632715, lat = 29.7632836), zoom = 10, size = c(640,640),
@@ -334,7 +346,7 @@ get_googlemap <- function(
   class(map) <- c("ggmap","raster")
 
   # map spatial info
-  if(is.character(center)) center <- as.numeric(geocode(center))
+  if(is.character(center)) center <- as.numeric(geocode(center, source = "google"))
   ll <- XY2LatLon(
     list(lat = center[2], lon = center[1], zoom = zoom),
     -size[1]/2 + 0.5,
@@ -350,6 +362,11 @@ get_googlemap <- function(
     ur.lat = ur[1], ur.lon = ur[2]
   )
 
+  # additional map meta-data
+  attr(map, "source")  <- "google"
+  attr(map, "maptype") <- maptype
+  attr(map, "zoom")    <- zoom
+
   # transpose
   out <- t(map)
 
@@ -367,6 +384,40 @@ get_googlemap <- function(
 
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 get_googlemap_checkargs <- function(args){
   eargs <- lapply(args, eval)
   argsgiven <- names(args)
