@@ -1,29 +1,33 @@
 #' Quick map plot
 #'
-#' \code{qmplot} is the ggmap equivalent to the ggplot2 function qplot and allows for
-#' the quick plotting of maps with data/models/etc.
+#' \code{qmplot} is the ggmap equivalent to the ggplot2 function qplot and
+#' allows for the quick plotting of maps with data/models/etc.
 #'
 #'
 #' @param x longitude values
 #' @param y latitude values
 #' @param ... other aesthetics passed for each layer
-#' @param data data frame to use (optional).  If not specified, will create
-#'   one, extracting vectors from the current environment.
+#' @param data data frame to use (optional).  If not specified, will create one,
+#'   extracting vectors from the current environment.
 #' @param zoom map zoom, see \code{\link{get_map}}
 #' @param source map source, see \code{\link{get_map}}
 #' @param maptype map type, see \code{\link{get_map}}
-#' @param extent how much of the plot should the map take up? "normal", "panel", or "device" (default)
-#' @param legend "left", "right" (default), "bottom", "top", "bottomleft", "bottomright", "topleft", "topright", "none" (used with extent = "device")
-#' @param padding distance from legend to corner of the plot  (used with extent = "device")
+#' @param extent how much of the plot should the map take up? "normal", "panel",
+#'   or "device" (default)
+#' @param legend "left", "right" (default), "bottom", "top", "bottomleft",
+#'   "bottomright", "topleft", "topright", "none" (used with extent = "device")
+#' @param padding distance from legend to corner of the plot  (used with extent
+#'   = "device")
 #' @param force force new map (don't use archived version)
-#' @param darken vector of the form c(number, color), where number is in [0, 1] and color is a character string indicating the color of the darken.  0 indicates no darkening, 1 indicates a black-out.
+#' @param darken vector of the form c(number, color), where number is in [0, 1]
+#'   and color is a character string indicating the color of the darken.  0
+#'   indicates no darkening, 1 indicates a black-out.
 #' @param mapcolor color ("color") or black-and-white ("bw")
 #' @param facets faceting formula to use.  Picks \code{\link{facet_wrap}} or
-#'   \code{\link{facet_grid}} depending on whether the formula is one sided
-#'   or two-sided
+#'   \code{\link{facet_grid}} depending on whether the formula is one sided or
+#'   two-sided
 #' @param margins whether or not margins will be displayed
-#' @param geom character vector specifying geom to use.  defaults to
-#'  "point"
+#' @param geom character vector specifying geom to use.  defaults to "point"
 #' @param stat character vector specifying statistics to use
 #' @param position character vector giving position adjustment to use
 #' @param xlim limits for x axis
@@ -34,8 +38,8 @@
 #' @param ylab character vector or expression for y axis label
 #' @export
 #' @examples
-#' \dontrun{
-#' # these are skipped to conserve R check time
+#'
+#' \dontrun{ # these are skipped to conserve R check time
 #'
 #' qmplot(lon, lat, data = crime)
 #'
@@ -48,11 +52,10 @@
 #' )
 #'
 #' # rank violent crimes
-#' violent_crimes$offense <-
-#'   factor(violent_crimes$offense,
-#'     levels = c("robbery", "aggravated assault",
-#'       "rape", "murder")
-#'   )
+#' violent_crimes$offense <- factor(
+#'   violent_crimes$offense,
+#'   levels = c("robbery", "aggravated assault", "rape", "murder")
+#' )
 #'
 #' # restrict to downtown
 #' violent_crimes <- subset(violent_crimes,
@@ -62,25 +65,19 @@
 #'
 #' theme_set(theme_bw())
 #'
-#' qmplot(lon, lat, data = violent_crimes, colour = offense, darken = .5,
+#' qmplot(lon, lat, data = violent_crimes, colour = offense,
 #'   size = I(3.5), alpha = I(.6), legend = "topleft")
 #'
 #' qmplot(lon, lat, data = violent_crimes, geom = c("point","density2d"))
 #' qmplot(lon, lat, data = violent_crimes) + facet_wrap(~ offense)
 #' qmplot(lon, lat, data = violent_crimes, extent = "panel") + facet_wrap(~ offense)
-#' qmplot(lon, lat, data = violent_crimes, extent = "panel", colour = offense,
-#'     darken = .4) +
+#' qmplot(lon, lat, data = violent_crimes, extent = "panel", colour = offense, darken = .4) +
 #'   facet_wrap(~ month)
 #'
 #'
 #'
 #'
-#' # doesn't quite work yet.... http://tile.stamen.com/terrain/#4/30.28/-87.21
 #' qmplot(long, lat, xend = long + delta_long,
-#'   yend = lat + delta_lat, data = seals, geom = "segment")
-#'
-#' # this works though!
-#' qmplot(long, lat, xend = long + delta_long, maptype = "toner-lite",
 #'   color = I("red"), yend = lat + delta_lat, data = seals,
 #'   geom = "segment", zoom = 5)
 #'
@@ -122,7 +119,6 @@
 #' # executing, but leave the code as a kind of case-study
 #' # they also require the rgdal library
 #'
-#' if(FALSE){
 #'
 #' library(lattice)
 #' library(sp)
@@ -131,20 +127,30 @@
 #' # load in and format the meuse dataset (see bivand, pebesma, and gomez-rubio)
 #' data(meuse)
 #' coordinates(meuse) <- c("x", "y")
-#' coordinates(meuse) <- ~x+y
 #' proj4string(meuse) <- CRS("+init=epsg:28992")
 #' meuse <- spTransform(meuse, CRS("+proj=longlat +datum=WGS84"))
 #'
 #' # plot
 #' plot(meuse)
 #'
-#' df <- as.data.frame(slot(meuse, "coords"))
-#' df <- data.frame(df, slot(meuse, "data"))
+#' m <- data.frame(slot(meuse, "coords"), slot(meuse, "data"))
+#' names(m)[1:2] <- c("lon", "lat")
+#'
+#' qmplot(lon, lat, data = m)
+#' qmplot(lon, lat, data = m, zoom = 14)
+#'
+#'
+#' qmplot(lon, lat, data = m, size = zinc,
+#'   zoom = 14, source = "google", maptype = "satellite",
+#'   alpha = I(.75), color = I("green"),
+#'   legend = "topleft", darken = .2
+#' ) + scale_size("Zinc (ppm)")
+#'
+#'
+#'
+#'
+#'
 #'
-#' qmplot(x, y, size = cadmium, alpha = I(.75), color = I("green"),
-#'   data = df, zoom = 14, legend = "topleft",
-#'   source = "google", maptype = "satellite", darken = .2
-#' ) + scale_size("Cadmium\n(ppm)")
 #'
 #'
 #' # load in the meuse.grid dataset (looking toward kriging)
@@ -153,79 +159,100 @@
 #' coordinates(meuse.grid) <- c("x", "y")
 #' proj4string(meuse.grid) <- CRS("+init=epsg:28992")
 #' meuse.grid <- spTransform(meuse.grid, CRS("+proj=longlat +datum=WGS84"))
-#' mg <- as.data.frame(slot(meuse.grid, "coords"))
-#' mg <- data.frame(mg, slot(meuse.grid, "data"))
 #'
 #' # plot it
-#' qmplot(x, y, data = mg, source = "google")
+#' plot(meuse.grid)
+#'
+#' mg <- data.frame(slot(meuse.grid, "coords"), slot(meuse.grid, "data"))
+#' names(mg)[1:2] <- c("lon", "lat")
+#'
+#' qmplot(lon, lat, data = mg, shape = I(15), zoom = 14, legend = "topleft") +
+#'   geom_point(aes(size = zinc), data = m, color = "green") +
+#'   scale_size("Zinc (ppm)")
 #'
 #'
-#' # using linear regression - surface trend analysis
-#' tsa <- krige(log(zinc) ~ 1, meuse, meuse.grid)
-#' mg$pred <- slot(tsa, "data")$var1.pred
-#' qmplot(x, y, data = mg, source = "google", color = pred,
-#'     size = I(2.5), shape = I(15),
-#'     alpha = I(3/5), darken = .3, legend = "topleft") +
-#'   scale_color_gradient("Predicted\nLog Zinc",
-#'     low = "green", high = "red"
-#'   )
 #'
+#' # interpolate at unobserved locations (i.e. at meuse.grid points)
+#' # pre-define scale for consistency
+#' scale <- scale_color_gradient("Predicted\nZinc (ppm)",
+#'   low = "green", high = "red", lim = c(100, 1850)
+#' )
+#'
+#'
+#'
+#' # inverse distance weighting
+#' idw <- idw(log(zinc) ~ 1, meuse, meuse.grid, idp = 2.5)
+#' mg$idw <- exp(slot(idw, "data")$var1.pred)
+#'
+#' qmplot(lon, lat, data = mg, shape = I(15), color = idw,
+#'   zoom = 14, legend = "topleft", alpha = I(.75), darken = .4
+#' ) + scale
+#'
+#'
+#'
+#' # linear regression
+#' lin <- krige(log(zinc) ~ 1, meuse, meuse.grid, degree = 1)
+#' mg$lin <- exp(slot(idw, "lin")$var1.pred)
+#'
+#' qmplot(lon, lat, data = mg, shape = I(15), color = lin,
+#'   zoom = 14, legend = "topleft", alpha = I(.75), darken = .4
+#' ) + scale
+#'
+#'
+#'
+#' # trend surface analysis
 #' tsa <- krige(log(zinc) ~ 1, meuse, meuse.grid, degree = 2)
-#' mg$pred <- slot(tsa, "data")$var1.pred
-#' qmplot(x, y, data = mg, source = "google", color = pred,
-#'     size = I(2.5), shape = I(15),
-#'     alpha = I(3/5), darken = .3, legend = "topleft") +
-#'   scale_color_gradient("Predicted\nLog Zinc",
-#'     low = "green", high = "red"
-#'   )
+#' mg$tsa <- exp(slot(tsa, "data")$var1.pred)
+#'
+#' qmplot(lon, lat, data = mg, shape = I(15), color = tsa,
+#'   zoom = 14, legend = "topleft", alpha = I(.75), darken = .4
+#' ) + scale
+#'
 #'
 #'
 #' # ordinary kriging
-#' vgram <- variogram(log(zinc) ~ sqrt(dist), meuse)
-#' vgramFit <- fit.variogram(vgram, vgm(1, "Exp", 300, 1))
-#' ordinaryKrige <- krige(log(zinc) ~ 1, meuse, meuse.grid, vgramFit)
-#' mg$pred <- slot(ordinaryKrige, "data")$var1.pred
-#' qmplot(x, y, data = mg, source = "google", color = pred,
-#'     size = I(2.5), shape = I(15),
-#'     alpha = I(3/5), darken = .3, legend = "topleft") +
-#'   scale_color_gradient("Predicted\nLog Zinc",
-#'     low = "green", high = "red"
-#'   )
+#' vgram <- variogram(log(zinc) ~ 1, meuse)   # plot(vgram)
+#' vgramFit <- fit.variogram(vgram, vgm(1, "Exp", .2, .1))
+#' ordKrige <- krige(log(zinc) ~ 1, meuse, meuse.grid, vgramFit)
+#' mg$ordKrige <- exp(slot(ordKrige, "data")$var1.pred)
+#'
+#' qmplot(lon, lat, data = mg, shape = I(15), color = ordKrige,
+#'   zoom = 14, legend = "topleft", alpha = I(.75), darken = .4
+#' ) + scale
+#'
+#'
 #'
 #' # universal kriging
-#' universalKrige <- krige(log(zinc) ~ sqrt(dist), meuse, meuse.grid, vgramFit)
-#' mg$pred <- slot(universalKrige, "data")$var1.pred
-#' qmplot(x, y, data = mg, source = "google", color = pred,
-#'     size = I(2.5), shape = I(15),
-#'     alpha = I(3/4), darken = .3, legend = "topleft") +
-#'   scale_color_gradient("Predicted\nLog Zinc",
-#'     low = "green", high = "red"
-#'   )
+#' vgram <- variogram(log(zinc) ~ 1, meuse) # plot(vgram)
+#' vgramFit <- fit.variogram(vgram, vgm(1, "Exp", .2, .1))
+#' univKrige <- krige(log(zinc) ~ sqrt(dist), meuse, meuse.grid, vgramFit)
+#' mg$univKrige <- exp(slot(univKrige, "data")$var1.pred)
+#'
+#' qmplot(lon, lat, data = mg, shape = I(15), color = univKrige,
+#'   zoom = 14, legend = "topleft", alpha = I(.75), darken = .4
+#' ) + scale
 #'
 #'
 #'
-#' # kriging with data
-#' qmplot(x, y, data = mg, source = "google", color = pred,
-#'     size = I(2.5), shape = I(15),
-#'     alpha = I(3/4), darken = .3, legend = "topleft") +
-#'   scale_color_gradient("Predicted\nLog Zinc",
-#'     low = "green", high = "red"
-#'   ) +
+#' # adding observed data layer
+#' qmplot(lon, lat, data = mg, shape = I(15), color = univKrige,
+#'   zoom = 14, legend = "topleft", alpha = I(.75), darken = .4
+#' ) +
 #'   geom_point(
-#'     aes(x = x, y = y, size = log(zinc)), data = df,
-#'     color = "black", alpha = 1/2
+#'     aes(x = lon, y = lat, size = zinc),
+#'     data = m, shape = 1, color = "black"
 #'   ) +
+#'   scale +
 #'   scale_size("Observed\nLog Zinc")
 #'
 #'
 #'
-#' } # end FALSE if
 #'
 #'
 #'
 #' } # end dontrun
 #'
-qmplot <- function(x, y, ..., data, zoom, source = "stamen", maptype = "terrain",
+qmplot <- function(x, y, ..., data, zoom, source = "stamen", maptype = "toner-lite",
   extent = "device", legend = "right", padding = .02, force = FALSE,
   darken = c(0, "black"), mapcolor = "color",
   facets = NULL, margins = FALSE, geom = "auto", stat = list(NULL),
@@ -240,7 +267,7 @@ qmplot <- function(x, y, ..., data, zoom, source = "stamen", maptype = "terrain"
   argsgiven <- names(args)
   if("mapcolour" %in% argsgiven) mapcolor <- eval(args$mapcolour)
 
-  .all_aesthetics <- unlist(getAnywhere(.all_aesthetics)[1:42])
+  .all_aesthetics <- unlist(.all_aesthetics[1:42])
   aesthetics <- compact(arguments[.all_aesthetics])
   aesthetics <- aesthetics[!is.constant(aesthetics)]
   aes_names <- names(aesthetics)
